import 'dart:convert';

import 'package:minecraft_yggdrasil/minecraft_yggdrasil.dart';
import 'package:shelf/shelf.dart';
import 'package:shelf/shelf_io.dart' as shelf_io;

var testProfile = {"test1@test.com": "112233"};

yggdrasilServer(int port) async {
  shelf_io.serve(Pipeline().addHandler(_yggdrasilHandle), 'localhost', port);
}

Future<Response> _yggdrasilHandle(Request request) async {
  if (request.method.toLowerCase() != "post") {
    return Response.badRequest(
      body: jsonEncode(
        ErrorResponse(
            error: "Method Not Allowed",
            errorMessage:
                "The method specified in the request is not allowed for the resource identified by the request URI"),
      ),
    );
  }

  var content = await request.readAsString();

  switch (request.url.toString()) {
    case "authenticate":
      {
        var t = AuthenticateRequest.fromJson(jsonDecode(content));

        if (!testProfile.containsKey(t.username)) {
          return Response.forbidden(
            jsonEncode(
              ErrorResponse(
                      error: "ForbiddenOperationException",
                      errorMessage:
                          "Invalid credentials. Invalid username or password.")
                  .toJson(),
            ),
          );
        }

        return Response.ok(request.url.toString());
      }
    case "invalidate":
    case "refresh":
    case "signout":
    case "validate":
    default:
  }

  return Response.ok(request.url.toString());
}
